% Auto-generated chapter 16 for nasai
% Hadiths in this chapter: 45

\hadithdefcmd{nasai}{1459}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏‏ "‏‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ تَعَالَى لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّ اللَّهَ عَزَّ وَجَلَّ يُخَوِّفُ بِهِمَا عِبَادَهُ ‏‏"‏‏ ‏‏.‏‏\hadithno{1459}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Bakrah said:"The Messenger of Allah (ﷺ) said: 'The sun and moon are two signs of Allah (SWT), the Most High, and they do not become eclipsed for death or birth of anyone, rather Allah (SWT), the Mighty and Sublime, strikes fear into His slaves through them}}
\hadithdefcmd{nasai}{1460}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو هِشَامٍ، - وَهُوَ الْمُغِيرَةُ بْنُ سَلَمَةَ - قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا أَبُو مَسْعُودٍ الْجُرَيْرِيُّ، عَنْ حَيَّانَ بْنِ عُمَيْرٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَمُرَةَ، قَالَ بَيْنَا أَنَا أَتَرَامَى، بِأَسْهُمٍ لِي بِالْمَدِينَةِ إِذِ انْكَسَفَتِ الشَّمْسُ فَجَمَعْتُ أَسْهُمِي وَقُلْتُ لأَنْظُرَنَّ مَا أَحْدَثَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي كُسُوفِ الشَّمْسِ فَأَتَيْتُهُ مِمَّا يَلِي ظَهْرَهُ وَهُوَ فِي الْمَسْجِدِ فَجَعَلَ يُسَبِّحُ وَيُكَبِّرُ وَيَدْعُو حَتَّى حُسِرَ عَنْهَا - قَالَ - ثُمَّ قَامَ فَصَلَّى رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ ‏‏.‏‏\hadithno{1460}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdur-Rahman bin Samurah said:"While I was (practicing) shooting some arrows in Al-Madinah, the sun became eclipsed. I gathered up my arrows and said: 'I want to see what the Messenger of Allah (ﷺ) will say about the eclipse of the sun.' So I came to him from behind when he was in the masjid, and he started to say the tasbih and takbir and to supplicate until the eclipse was over. Then he stood up and prayed two rak'ahs with four prostrations}}
\hadithdefcmd{nasai}{1461}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏‏ "‏‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ تَعَالَى فَإِذَا رَأَيْتُمُوهُمَا فَصَلُّوا ‏‏"‏‏ ‏‏.‏‏\hadithno{1461}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that:The Messenger of Allah (ﷺ) said: "The sun and moon do not become eclipsed for death or birth of anyone, rather they are two of the signs of Allah (SWT) the Most High, so when you see that then pray}}
\hadithdefcmd{nasai}{1462}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي قَيْسٌ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏‏ "‏‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ عَزَّ وَجَلَّ فَإِذَا رَأَيْتُمُوهُمَا فَصَلُّوا ‏‏"‏‏ ‏‏.‏‏\hadithno{1462}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Mas'ud said:"The Messenger of Allah (ﷺ) said: "The sun and the moon do not become eclipsed for the death or birth of anyone, rather they are two of the signs of Allah (SWT), the Mighty and Sublime, so when you see that then pray}}
\hadithdefcmd{nasai}{1463}{أَخْبَرَنَا مُحَمَّدُ بْنُ كَامِلٍ الْمَرْوَزِيُّ، عَنْ هُشَيْمٍ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏‏ "‏‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ عَزَّ وَجَلَّ وَإِنَّهُمَا لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمُوهُمَا فَصَلُّوا حَتَّى تَنْجَلِيَ ‏‏"‏‏ ‏‏.‏‏\hadithno{1463}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Bakrah said:"The Messenger of Allah (ﷺ) said: 'The sun and moon are two signs of Allah(ﷺ), and they do not become eclipsed for the death or birth of anyone. If you see that then pray until it (the eclipse) is over}}
\hadithdefcmd{nasai}{1464}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا أَشْعَثُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ كُنَّا جُلُوسًا مَعَ النَّبِيِّ صلى الله عليه وسلم فَكَسَفَتِ الشَّمْسُ فَوَثَبَ يَجُرُّ ثَوْبَهُ فَصَلَّى رَكْعَتَيْنِ حَتَّى انْجَلَتْ ‏‏.‏‏\hadithno{1464}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Bakrah said:"We were sitting with the Prophet (ﷺ) when the sun became eclipsed. He leapt up, dragging his garment and prayed two rak'ahs until the eclipse was over}}
\hadithdefcmd{nasai}{1465}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ خَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم مُنَادِيًا يُنَادِي أَنَّ الصَّلاَةَ جَامِعَةً فَاجْتَمَعُوا وَاصْطَفُّوا فَصَلَّى بِهِمْ أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ ‏‏.‏‏\hadithno{1465}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The sun was eclipsed during the time of the Messenger of Allah (ﷺ), and the Prophet (ﷺ) commanded a caller to call out that prayer was about to begin in congregation. So they gathered and formed rows, and he led them in prayer, bowing four times in two rak'ahs and prostrating four times}}
\hadithdefcmd{nasai}{1466}{أَخْبَرَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خَلِيٍّ، قَالَ حَدَّثَنَا بِشْرُ بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَسَفَتِ الشَّمْسُ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمَسْجِدِ فَقَامَ فَكَبَّرَ وَصَفَّ النَّاسُ وَرَاءَهُ فَاسْتَكْمَلَ أَرْبَعَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ وَانْجَلَتِ الشَّمْسُ قَبْلَ أَنْ يَنْصَرِفَ ‏‏.‏‏\hadithno{1466}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Urwah bin Az-Zubair narrated that 'Aishah, the wife of the Prophet (ﷺ) said:"The sun was eclipsed during the life of the Prophet (ﷺ). The Messenger of Allah (ﷺ) went out to the masjid and stood and said the takbir, and the people formed rows behind him. He bowed four times and prostrated four times, and the eclipse ended before he finished}}
\hadithdefcmd{nasai}{1467}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ إِسْمَاعِيلَ ابْنِ عُلَيَّةَ، قَالَ حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى عِنْدَ كُسُوفِ الشَّمْسِ ثَمَانِيَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ ‏‏.‏‏ وَعَنْ عَطَاءٍ مِثْلُ ذَلِكَ ‏‏.‏‏\hadithno{1467}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Tawus from Ibn Abbas, that :The Messenger of Allah (ﷺ) prayed when the sun was eclipsed, bowing eight times and prostrating four times}}
\hadithdefcmd{nasai}{1468}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى فِي كُسُوفٍ فَقَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثُمَّ سَجَدَ وَالأُخْرَى مِثْلُهَا ‏‏.‏‏\hadithno{1468}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Tawus from Ibn Abbas that:The Prophet (ﷺ) prayed when there was an eclipse. He recited then he bowed, then he recited then he bowed, then he recited then he bowed, then he recited then he bowed, then he prostrated, and he did the second rak'ahs in same fashion}}
\hadithdefcmd{nasai}{1469}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنِ ابْنِ نَمِرٍ، - وَهُوَ عَبْدُ الرَّحْمَنِ بْنُ نَمِرٍ - عَنِ الزُّهْرِيِّ، عَنْ كَثِيرِ بْنِ عَبَّاسٍ، ح وَأَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي كَثِيرُ بْنُ عَبَّاسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى يَوْمَ كَسَفَتِ الشَّمْسُ أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ ‏‏.‏‏\hadithno{1469}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Kathir bin Abbas, from Abdullah bin Abbas that:The Messenger of Allah (ﷺ) prayed on the day the sun was eclipsed, bowing four times in two rak'ahs and prostrating four times}}
\hadithdefcmd{nasai}{1470}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ سَمِعْتُ عُبَيْدَ بْنَ عُمَيْرٍ، يُحَدِّثُ قَالَ حَدَّثَنِي مَنْ، أُصَدِّقُ فَظَنَنْتُ أَنَّهُ يُرِيدُ عَائِشَةَ أَنَّهَا قَالَتْ كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ بِالنَّاسِ قِيَامًا شَدِيدًا يَقُومُ بِالنَّاسِ ثُمَّ يَرْكَعُ ثُمَّ يَقُومُ ثُمَّ يَرْكَعُ ثُمَّ يَقُومُ ثُمَّ يَرْكَعُ فَرَكَعَ رَكْعَتَيْنِ فِي كُلِّ رَكْعَةٍ ثَلاَثَ رَكَعَاتٍ رَكَعَ الثَّالِثَةَ ثُمَّ سَجَدَ حَتَّى إِنَّ رِجَالاً يَوْمَئِذٍ يُغْشَى عَلَيْهِمْ حَتَّى إِنَّ سِجَالَ الْمَاءِ لَتُصَبُّ عَلَيْهِمْ مِمَّا قَامَ بِهِمْ يَقُولُ إِذَا رَكَعَ ‏‏"‏‏ اللَّهُ أَكْبَرُ ‏‏"‏‏ ‏‏.‏‏ وَإِذَا رَفَعَ رَأْسَهُ ‏‏"‏‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏‏"‏‏ ‏‏.‏‏ فَلَمْ يَنْصَرِفْ حَتَّى تَجَلَّتِ الشَّمْسُ فَقَامَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَقَالَ ‏‏"‏‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنْ آيَتَانِ مِنْ آيَاتِ اللَّهِ يُخَوِّفُكُمْ بِهِمَا فَإِذَا كَسَفَا فَافْزَعُوا إِلَى ذِكْرِ اللَّهِ عَزَّ وَجَلَّ حَتَّى يَنْجَلِيَا ‏‏"‏‏ ‏‏.‏‏\hadithno{1470}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ata said:"I heard Ubaid bin Umair say: 'Someone whom I trust'- and I think he meant Aishah- told me: There was an eclipse of the sun during the time of the Messenger of Allah (ﷺ). He led the people in prayer and stood for a very long time, then he bowed, then he stood, then he bowed, then he stood, then he bowed. He prayed two rak'ahs, bowing three times in each rak'ah. After bowing for the third time he prostrated for a long time. Some men fainted on that day and had to be revived by having buckets of water thrown over them, because of having stood for so log. When he bowed, he said: Allahu Akbar, and when he raised his head, he said: Sami' Allahu lima hamidah.He did not finish until the eclipse had ended. Then he stood and praised and glorified Allah (SWT) and said: The sun and moon do not eclipse for the death or birth of anyone, but they are two of the signs of Allah (SWT) with which He strikes fear unto you. If they are eclipsed then turn to the remembrance of Allah, the Mighty and Sublime, until it (the eclipse) is over}}
\hadithdefcmd{nasai}{1471}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، فِي صَلاَةِ الآيَاتِ عَنْ عَطَاءٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى سِتَّ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ ‏‏.‏‏ قُلْتُ لِمُعَاذٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ لاَ شَكَّ وَلاَ مِرْيَةَ ‏‏.‏‏\hadithno{1471}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated fom 'Ata from Ibn 'Umair, from Aishah, that:The Prophet (ﷺ) prayed, bowing six times and prostrating four times. "I said to Mu'adh: 'Is this from the Prophet (ﷺ)?' He said: 'Without a doubt}}
\hadithdefcmd{nasai}{1472}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ ابْنِ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ خَسَفَتِ الشَّمْسُ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ فَكَبَّرَ وَصَفَّ النَّاسُ وَرَاءَهُ فَاقْتَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم قِرَاءَةً طَوِيلَةً ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏‏"‏‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏‏"‏‏ ‏‏.‏‏ ثُمَّ قَامَ فَاقْتَرَأَ قِرَاءَةً طَوِيلَةً هِيَ أَدْنَى مِنَ الْقِرَاءَةِ الأُولَى ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً هُوَ أَدْنَى مِنَ الرُّكُوعِ الأَوَّلِ ثُمَّ قَالَ ‏‏"‏‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏‏"‏‏ ‏‏.‏‏ ثُمَّ سَجَدَ ثُمَّ فَعَلَ فِي الرَّكْعَةِ الأُخْرَى مِثْلَ ذَلِكَ فَاسْتَكْمَلَ أَرْبَعَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ وَانْجَلَتِ الشَّمْسُ قَبْلَ أَنْ يَنْصَرِفَ ثُمَّ قَامَ فَخَطَبَ النَّاسَ فَأَثْنَى عَلَى اللَّهِ عَزَّ وَجَلَّ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏‏"‏‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ تَعَالَى لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمُوهُمَا فَصَلُّوا حَتَّى يُفْرَجَ عَنْكُمْ ‏‏"‏‏ ‏‏.‏‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏‏"‏‏ رَأَيْتُ فِي مَقَامِي هَذَا كُلَّ شَىْءٍ وُعِدْتُمْ لَقَدْ رَأَيْتُمُونِي أَرَدْتُ أَنْ آخُذَ قِطْفًا مِنَ الْجَنَّةِ حِينَ رَأَيْتُمُونِي جَعَلْتُ أَتَقَدَّمُ وَلَقَدْ رَأَيْتُ جَهَنَّمَ يَحْطِمُ بَعْضُهَا بَعْضًا حِينَ رَأَيْتُمُونِي تَأَخَّرْتُ وَرَأَيْتُ فِيهَا ابْنَ لُحَىٍّ وَهُوَ الَّذِي سَيَّبَ السَّوَائِبَ ‏‏"‏‏ ‏‏.‏‏\hadithno{1472}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Shihab rom 'Urwah bin Az-Zubair, that Aishah said:"The sun was eclipsed during the lifetime of the Messenger of Allah (ﷺ). He stood and said the takbir, and the people formed rows behind him. The Messenger of Allah (ﷺ) recited for a long time, then he said the takbir and bowed for a long time, then he raised his head and said: Sami Allahu liman hamidah, Rabbana wa lakal-hamd. Then he stood and recited for a long time, but it was a shorter recitation than the first recitation, then he said the takbir and bowed but it was shorter than the first bowing. Then he said: Sami Allahu liman hamidah, then he prostrated. In this manner, he bowed four times, and the eclipse ended before he had finished. Then he stood and addressed the people. He praised and glorified Allah (SWT), the Mighty and Sublime, as He deserves, then he said: The sun and moon are two of the signs of Allah (SWT), Most High. They do not become eclipsed for the death or birth of anyone. If you see that (eclipsed) then pray until it ends. And the Messenger of Allah (ﷺ) said: While I was standing just now I saw everything you have been promised. When you saw me moving forward, I wanted to take a cluster of fruit from Paradise. And I saw Hell; parts of it were consuming other parts when you saw me step backward. And I saw therein Ibn Luhayy, who was the first one to establish the Sa'ibah}}
\hadithdefcmd{nasai}{1473}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ خَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنُودِيَ الصَّلاَةُ جَامِعَةٌ فَاجْتَمَعَ النَّاسُ فَصَلَّى بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ ‏‏.‏‏\hadithno{1473}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Az-Zuhri, from 'Urwah, that :Aishah said: "The sun was eclipsed during the lifetime of the Messenger of Allah (ﷺ) and it was called out: 'As-salatu jam'iah (prayer is about to begin in congregation).' So the people gathered and the Messenger of Allah (ﷺ) led them in prayer, bowing four times in two rak'ahs and prostrating four times}}
\hadithdefcmd{nasai}{1474}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَسَفَتِ الشَّمْسُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّاسِ فَقَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ قَامَ فَأَطَالَ الْقِيَامَ وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ وَهُو دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ فَسَجَدَ ثُمَّ فَعَلَ ذَلِكَ فِي الرَّكْعَةِ الأُخْرَى مِثْلَ ذَلِكَ ثُمَّ انْصَرَفَ وَقَدْ تَجَلَّتِ الشَّمْسُ فَخَطَبَ النَّاسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏‏"‏‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمْ ذَلِكَ فَادْعُوا اللَّهَ عَزَّ وَجَلَّ وَكَبِّرُوا وَتَصَدَّقُوا ‏‏"‏‏ ‏‏.‏‏ ثُمَّ قَالَ ‏‏"‏‏ يَا أُمَّةَ مُحَمَّدٍ مَا مِنْ أَحَدٍ أَغْيَرُ مِنَ اللَّهِ عَزَّ وَجَلَّ أَنْ يَزْنِيَ عَبْدُهُ أَوْ تَزْنِيَ أَمَتُهُ يَا أُمَّةَ مُحَمَّدٍ وَاللَّهِ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏‏"‏‏ ‏‏.‏‏\hadithno{1474}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Hisham bin 'Urwah, from his father, that 'Aishah said:'The sun was eclipsed during the time of the Messenger of Allah (ﷺ) and the Messenger of Allah (ﷺ) led the people in prayer. He stood for a long time, then he bowed for a long time, then he stood for a long time, but it was shorter than the first standing, then he bowed for a long time but it was shorter than the first bowing. Then he stood up, then he prostrated, then he did the same in the second rak'ah, and when he finished the eclipse had ended. Then he addressed the people; he praised and glorified Allah (SWT), then he said: The sun and the moon are two of the signs of Allah (SWT). They do not become eclipsed for the death or birth of anyone. If you see that then call upon Allah (SWT), the Mighty and Sublime, and magnify Him, and give charity. Then he said: 'O Ummah of Muhammad! There is no one more jealous than Allah (SWT), the Mighty and Sublime, when his male or female slave commits zina. O Ummah of Muhammad! By Allah, if you knew what I know, you would laugh little and weep much}}
\hadithdefcmd{nasai}{1475}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ ابْنِ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عَمْرَةَ، حَدَّثَتْهُ أَنَّ عَائِشَةَ حَدَّثَتْهَا أَنَّ يَهُودِيَّةً أَتَتْهَا فَقَالَتْ أَجَارَكِ اللَّهُ مِنْ عَذَابِ الْقَبْرِ قَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ إِنَّ النَّاسَ لَيُعَذَّبُونَ فِي الْقُبُورِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَائِذًا بِاللَّهِ ‏‏.‏‏ قَالَتْ عَائِشَةُ إِنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ مَخْرَجًا فَخَسَفَتِ الشَّمْسُ فَخَرَجْنَا إِلَى الْحُجْرَةِ فَاجْتَمَعَ إِلَيْنَا نِسَاءٌ وَأَقْبَلَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَذَلِكَ ضَحْوَةً فَقَامَ قِيَامًا طَوِيلاً ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ رَأْسَهُ فَقَامَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ دُونَ رُكُوعِهِ ثُمَّ سَجَدَ ثُمَّ قَامَ الثَّانِيَةَ فَصَنَعَ مِثْلَ ذَلِكَ إِلاَّ أَنَّ رُكُوعَهُ وَقِيَامَهُ دُونَ الرَّكْعَةِ الأُولَى ثُمَّ سَجَدَ وَتَجَلَّتِ الشَّمْسُ فَلَمَّا انْصَرَفَ قَعَدَ عَلَى الْمِنْبَرِ فَقَالَ فِيمَا يَقُولُ ‏‏ "‏‏ إِنَّ النَّاسَ يُفْتَنُونَ فِي قُبُورِهِمْ كَفِتْنَةِ الدَّجَّالِ ‏‏"‏‏ ‏‏.‏‏ قَالَتْ عَائِشَةُ كُنَّا نَسْمَعُهُ بَعْدَ ذَلِكَ يَتَعَوَّذُ مِنْ عَذَابِ الْقَبْرِ ‏‏.‏‏\hadithno{1475}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Yahya bin Sa'eed that :'Amrah told him that Aishah told her that a Jewish woman came to her and said: "May Allah protect you from the torment of the grave." Aishah said: "O Messenger of Allah, will people be tormented in the graves?" The Messenger of Allah (ﷺ) sought refuge with Allah. 'Aishah said: "The Prophet (ﷺ) went out, and the sun became eclipsed. We went out to another room and the women gathered with us. The Messenger of Allah (ﷺ) came to us and that was at the time of forenoon. He stood for a long time, then he bowed for a long time, then he raises his head and stood for a shorter time than the first one; then he bowed for a shorter time than the first one. Then he prostrated, then he stood up for the second (rak'ah) and did the same again, except that his bowing an prostrating were shorter than in the first rak'ah. Then he prostrated, and the eclipse had ended. When he had finished, he sat on the minbar and one of the things he said was: 'The people will be tried in their graves like the trial of the Dajjal.' Aishah siad: 'After that, we used to hear him seeking refuge with Allah (SWT) from the torment of the grave}}
\hadithdefcmd{nasai}{1476}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، - هُوَ الأَنْصَارِيُّ - قَالَ سَمِعْتُ عَمْرَةَ، قَالَتْ سَمِعْتُ عَائِشَةَ، تَقُولُ جَاءَتْنِي يَهُودِيَّةٌ تَسْأَلُنِي فَقَالَتْ أَعَاذَكِ اللَّهُ مِنْ عَذَابِ الْقَبْرِ ‏‏.‏‏ فَلَمَّا جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ يَا رَسُولَ اللَّهِ أَيُعَذَّبُ النَّاسُ فِي الْقُبُورِ فَقَالَ عَائِذًا بِاللَّهِ فَرَكِبَ مَرْكَبًا - يَعْنِي - وَانْخَسَفَتِ الشَّمْسُ فَكُنْتُ بَيْنَ الْحُجَرِ مَعَ نِسْوَةٍ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ مَرْكَبِهِ فَأَتَى مُصَلاَّهُ فَصَلَّى بِالنَّاسِ فَقَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ رَأْسَهُ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ رَأْسَهُ فَأَطَالَ الْقِيَامَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ قَامَ قِيَامًا أَيْسَرَ مِنْ قِيَامِهِ الأَوَّلِ ثُمَّ رَكَعَ أَيْسَرَ مِنْ رُكُوعِهِ الأَوَّلِ ثُمَّ رَفَعَ رَأْسَهُ فَقَامَ أَيْسَرَ مِنْ قِيَامِهِ الأَوَّلِ ثُمَّ رَكَعَ أَيْسَرَ مِنْ رُكُوعِهِ الأَوَّلِ ثُمَّ رَفَعَ رَأْسَهُ فَقَامَ أَيْسَرَ مِنْ قِيَامِهِ الأَوَّلِ فَكَانَتْ أَرْبَعَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ وَانْجَلَتِ الشَّمْسُ فَقَالَ ‏‏ "‏‏ إِنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ كَفِتْنَةِ الدَّجَّالِ ‏‏"‏‏ ‏‏.‏‏ قَالَتْ عَائِشَةُ فَسَمِعْتُهُ بَعْدَ ذَلِكَ يَتَعَوَّذُ مِنْ عَذَابِ الْقَبْرِ ‏‏.‏‏\hadithno{1476}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Amrah said:"I heard Aishah say: 'A Jewish woman came to me begging, and said: May Allah grant you protection from the torment of the grave.' When the Messenger of Allah (ﷺ) came, I said: 'O Messenger of Allah (ﷺ), will people be tormented in their graves?' He sought refuge with Allah (SWT) and climbed onto his mount. The sun became eclipsed while I was between the apartments with some women. The Messenger of Allah (ﷺ) came from his mount and came to his prayer place, and led the people in prayer.He stood for a long time, then he bowed for a long time, then he raised his head and stood for a long time, then he bowed for a long time, then he raised his head and stood for a long time, then he prostrated for a long time. Then he stood for a shorter time than in the first (rak'ah), then he bowed for a shorter time than the first, then he raised his head and stood for a shorter time than the first, then he bowed for a shorter time than the first, then he raised his head and stood for a shorter time than the first, so he bowed four times and prostrated four times, and the eclipse ended. He said: "You will be tried in your graves like the trial of the Dajjal.' Aishah said: 'I heard him after that seeking refuge with Allah from the torment of the grave}}
\hadithdefcmd{nasai}{1477}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ الرَّحِيمِ، قَالَ أَنْبَأَنَا ابْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي كُسُوفٍ فِي صُفَّةِ زَمْزَمَ أَرْبَعَ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ ‏‏.‏‏\hadithno{1477}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Aishah that:The Messenger of Allah (ﷺ) prayed during an eclipse in a shaded area near Zamzam, bowing four times and prostrating four times}}
\hadithdefcmd{nasai}{1478}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا أَبُو عَلِيٍّ الْحَنَفِيُّ، قَالَ حَدَّثَنَا هِشَامٌ، صَاحِبُ الدَّسْتَوَائِيِّ عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي يَوْمٍ شَدِيدِ الْحَرِّ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِأَصْحَابِهِ فَأَطَالَ الْقِيَامَ حَتَّى جَعَلُوا يَخِرُّونَ ثُمَّ رَكَعَ فَأَطَالَ ثُمَّ رَفَعَ فَأَطَالَ ثُمَّ رَكَعَ فَأَطَالَ ثُمَّ رَفَعَ فَأَطَالَ ثُمَّ سَجَدَ سَجْدَتَيْنِ ثُمَّ قَامَ فَصَنَعَ نَحْوًا مِنْ ذَلِكَ وَجَعَلَ يَتَقَدَّمُ ثُمَّ جَعَلَ يَتَأَخَّرُ فَكَانَتْ أَرْبَعَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ كَانُوا يَقُولُونَ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَخْسِفَانِ إِلاَّ لِمَوْتِ عَظِيمٍ مِنْ عُظَمَائِهِمْ وَإِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ يُرِيكُمُوهُمَا فَإِذَا انْخَسَفَتْ فَصَلُّوا حَتَّى تَنْجَلِيَ ‏‏.‏‏\hadithno{1478}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The sun eclipsed during the time of the Messenger of Allah (ﷺ) on a very hot day. The Messenger of Allah (ﷺ) led his companions in prayer, and he stood for so long that they started to fall over. Then he bowed for a long time, then he stood up (and remained standing) for a long time. Then he bowed again for a long time, then he stood up (again) and (remained standing) for a long time. Then he prostrated twice, then he stood up and did the same again. He started to move forward, then he started to step back. He bowed four times and prostrated four times. They used to say that eclipses of the sun and moon only happened when one of their great men died, but they are two of the signs of Allah (SWT) that He shows to you, so when an eclipse happens, pray until it is over}}
\hadithdefcmd{nasai}{1479}{أَخْبَرَنِي مَحْمُودُ بْنُ خَالِدٍ، عَنْ مَرْوَانَ، قَالَ حَدَّثَنِي مُعَاوِيَةُ بْنُ سَلاَّمٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ خَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَ فَنُودِيَ الصَّلاَةُ جَامِعَةٌ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّاسِ رَكْعَتَيْنِ وَسَجْدَةً ثُمَّ قَامَ فَصَلَّى رَكْعَتَيْنِ وَسَجْدَةً ‏.‏ قَالَتْ عَائِشَةُ مَا رَكَعْتُ رُكُوعًا قَطُّ وَلاَ سَجَدْتُ سُجُودًا قَطُّ كَانَ أَطْوَلَ مِنْهُ ‏.‏ خَالَفَهُ مُحَمَّدُ بْنُ حِمْيَرٍ ‏.‏\hadithno{1479}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abdullah bin 'Amr said:"The sun was eclipsed during the time of the Messenger of Allah (ﷺ), so he issued orders that the call be given: 'As-salatu jam'iah. The Messenger of Allah (ﷺ) led the people in prayer, bowing twice and prostrating twice. Then he stood and prayed, bowing twice and prostrating once. 'Aishah said: 'I never bowed or prostrated for so long as that}}
\hadithdefcmd{nasai}{1480}{أَخْبَرَنَا يَحْيَى بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا ابْنُ حِمْيَرٍ، عَنْ مُعَاوِيَةَ بْنِ سَلاَّمٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي طُعْمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ كَسَفَتِ الشَّمْسُ فَرَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ وَسَجْدَتَيْنِ ثُمَّ قَامَ فَرَكَعَ رَكْعَتَيْنِ وَسَجْدَتَيْنِ ثُمَّ جُلِّيَ عَنِ الشَّمْسِ ‏.‏ وَكَانَتْ عَائِشَةُ تَقُولُ مَا سَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم سُجُودًا وَلاَ رَكَعَ رُكُوعًا أَطْوَلَ مِنْهُ ‏.‏ خَالَفَهُ عَلِيُّ بْنُ الْمُبَارَكِ ‏.‏\hadithno{1480}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The sun was eclipsed and the Messenger of Allah (ﷺ) bowed twice and prostrated twice, then he stood up and bowed twice and prostrated twice. Then the eclipse ended. 'Aishah used to say: "The Messenger of Allah (ﷺ) never prostrated or bowed for so long as that}}
\hadithdefcmd{nasai}{1481}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا أَبُو زَيْدٍ، سَعِيدُ بْنُ الرَّبِيعِ قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو حَفْصَةَ، مَوْلَى عَائِشَةَ أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّهُ، لَمَّا كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ وَأَمَرَ فَنُودِيَ أَنَّ الصَّلاَةَ جَامِعَةٌ فَقَامَ فَأَطَالَ الْقِيَامَ فِي صَلاَتِهِ ‏.‏ قَالَتْ عَائِشَةُ فَحَسِبْتُ قَرَأَ سُورَةَ الْبَقَرَةِ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ قَامَ مِثْلَ مَا قَامَ وَلَمْ يَسْجُدْ ثُمَّ رَكَعَ فَسَجَدَ ثُمَّ قَامَ فَصَنَعَ مِثْلَ مَا صَنَعَ رَكْعَتَيْنِ وَسَجْدَةً ثُمَّ جَلَسَ وَجُلِّيَ عَنِ الشَّمْسِ ‏.‏\hadithno{1481}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hafs, the freed slave of 'Aishah, narrated that 'Aishah told him:"When the sun was eclipsed during the time of the Messenger of Allah (ﷺ), he performed wudu' and ordered that the call be given: 'As-salatu jami'ah.' He stood for a long time in prayer," and 'Aishah said: "I thought that he recited Surah Al-Baqarah. Then he bowed for a long time, then he said: Sami' Allahu liman hamidah. Then he bowed, then prostrated. Then he stood up and did the same again, bowing twice and prostrating once. Then he sat and the eclipse ended}}
\hadithdefcmd{nasai}{1482}{أَخْبَرَنَا هِلاَلُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، قَالَ حَدَّثَنِي أَبِي السَّائِبُ، أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرٍو، حَدَّثَهُ قَالَ انْكَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الصَّلاَةِ وَقَامَ الَّذِينَ مَعَهُ فَقَامَ قِيَامًا فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ رَأْسَهُ وَسَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ رَفَعَ رَأْسَهُ وَجَلَسَ فَأَطَالَ الْجُلُوسَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ رَفَعَ رَأْسَهُ وَقَامَ فَصَنَعَ فِي الرَّكْعَةِ الثَّانِيَةِ مِثْلَ مَا صَنَعَ فِي الرَّكْعَةِ الأُولَى مِنَ الْقِيَامِ وَالرُّكُوعِ وَالسُّجُودِ وَالْجُلُوسِ فَجَعَلَ يَنْفُخُ فِي آخِرِ سُجُودِهِ مِنَ الرَّكْعَةِ الثَّانِيَةِ وَيَبْكِي وَيَقُولُ ‏"‏ لَمْ تَعِدْنِي هَذَا وَأَنَا فِيهِمْ لَمْ تَعِدْنِي هَذَا وَنَحْنُ نَسْتَغْفِرُكَ ‏"‏ ‏.‏ ثُمَّ رَفَعَ رَأْسَهُ وَانْجَلَتِ الشَّمْسُ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَطَبَ النَّاسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ عَزَّ وَجَلَّ فَإِذَا رَأَيْتُمْ كُسُوفَ أَحَدِهِمَا فَاسْعَوْا إِلَى ذِكْرِ اللَّهِ عَزَّ وَجَلَّ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَقَدْ أُدْنِيَتِ الْجَنَّةُ مِنِّي حَتَّى لَوْ بَسَطْتُ يَدِي لَتَعَاطَيْتُ مِنْ قُطُوفِهَا وَلَقَدْ أُدْنِيَتِ النَّارُ مِنِّي حَتَّى لَقَدْ جَعَلْتُ أَتَّقِيهَا خَشْيَةَ أَنْ تَغْشَاكُمْ حَتَّى رَأَيْتُ فِيهَا امْرَأَةً مِنْ حِمْيَرَ تُعَذَّبُ فِي هِرَّةٍ رَبَطَتْهَا فَلَمْ تَدَعْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ فَلاَ هِيَ أَطْعَمَتْهَا وَلاَ هِيَ سَقَتْهَا حَتَّى مَاتَتْ فَلَقَدْ رَأَيْتُهَا تَنْهَشُهَا إِذَا أَقْبَلَتْ وَإِذَا وَلَّتْ تَنْهَشُ أَلْيَتَهَا وَحَتَّى رَأَيْتُ فِيهَا صَاحِبَ السِّبْتِيَّتَيْنِ أَخَا بَنِي الدَّعْدَاعِ يُدْفَعُ بِعَصًا ذَاتِ شُعْبَتَيْنِ فِي النَّارِ وَحَتَّى رَأَيْتُ فِيهَا صَاحِبَ الْمِحْجَنِ الَّذِي كَانَ يَسْرِقُ الْحَاجَّ بِمِحْجَنِهِ مُتَّكِئًا عَلَى مِحْجَنِهِ فِي النَّارِ يَقُولُ أَنَا سَارِقُ الْمِحْجَنِ ‏"‏ ‏.‏\hadithno{1482}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin 'Amr said:"The sun eclipsed during the time of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) got up to pray, and those who were with him also got up. He stood for a long time, then he bowed for a long time, then he raised his head and (then) prostrated for a long time. Then he raised his head and sat for a long time. Then he prostrated for a long time, then he raised his head and stood up, and he did in the second rak'ah the same as he had done in the first, standing, bowing, prostrating and sitting. He started blowing and weeping at the end of his prostration in the second rak'ah, saying: 'You did not tell me that You would do that while I was still among them; You d not tell me that You would do that while we are asking You for forgiveness.' Then he raised his head and the eclipse ended. The Messenger of Allah (ﷺ) stood and addressed the people. He praised and glorified Allah then he said: "The sun and moon are two of the signs of Allah (SWT), the Mighty and Sublime. If you see either of them being eclipsed, then hasten to remember Allah (SWT), the Mighty and Sublime. By the One in Whose Hand is the soul of Muhammad, Paradise was brought so near to me that if I had stretched out my hand, I could have taken some of its fruits. And Hell was brought so near to me that I tried to ward it off for fear it may overwhelm you. I saw therein a woman from Himyar who was being punished because of a cat she tied up, not leaving it free to eat of the vermin of the earth, nor feeding it or giving it water, until it died. I saw it biting her when she came and biting her backside when she went. And I saw the owner of the Sabtiyatain, the brother of Banu As-Da'da, being pushed with a two-pronged stick in the Fire. And I saw the owner of the stick with a crooked end, who used to steal from the Hajj pilgrims with that crooked stick, leaning on his stick in Hell and saying: 'I am the thief with the crooked stick}}
\hadithdefcmd{nasai}{1483}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ بْنِ عَبْدِ الْعَظِيمِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ، سَبَلاَنُ قَالَ حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ الْمُهَلَّبِيُّ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ فَصَلَّى لِلنَّاسِ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ قَامَ فَأَطَالَ الْقِيَامَ وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ رَفَعَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ وَهُوَ دُونَ السُّجُودِ الأَوَّلِ ثُمَّ قَامَ فَصَلَّى رَكْعَتَيْنِ وَفَعَلَ فِيهِمَا مِثْلَ ذَلِكَ ثُمَّ سَجَدَ سَجْدَتَيْنِ يَفْعَلُ فِيهِمَا مِثْلَ ذَلِكَ حَتَّى فَرَغَ مِنْ صَلاَتِهِ ثُمَّ قَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ وَإِنَّهُمَا لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمْ ذَلِكَ فَافْزَعُوا إِلَى ذِكْرِ اللَّهِ عَزَّ وَجَلَّ وَإِلَى الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1483}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The sun eclipsed during the time of the Messenger of Allah (ﷺ). He stood and led the people in prayer. He stood for a long time, then he bowed for a long time, then he stood for a long time that was shorter than the first time, then he bowed for a long time that was shorter than the first time. Then he prostrated for a long time, then he sat up, then he prostrated for a long time that was shorter than the first time. Then he stood up and bowed twice again, doing the same again. Then he prostrated twice, doing the same again, until he had finished his prayer. Then he said: 'The sun and the moon are two of the signs of Allah (SWT), and they do not become eclipsed for the death or birth of anyone. If you see that then hasted to remember Allah (SWT) and pray}}
\hadithdefcmd{nasai}{1484}{أَخْبَرَنَا هِلاَلُ بْنُ الْعَلاَءِ بْنِ هِلاَلٍ، قَالَ حَدَّثَنَا الْحُسَيْنُ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا الأَسْوَدُ بْنُ قَيْسٍ، قَالَ حَدَّثَنِي ثَعْلَبَةُ بْنُ عِبَادٍ الْعَبْدِيُّ، مِنْ أَهْلِ الْبَصْرَةِ أَنَّهُ شَهِدَ خُطْبَةً يَوْمًا لِسَمُرَةَ بْنِ جُنْدُبٍ فَذَكَرَ فِي خُطْبَتِهِ حَدِيثًا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَمُرَةُ بْنُ جُنْدُبٍ بَيْنَا أَنَا يَوْمًا وَغُلاَمٌ مِنَ الأَنْصَارِ نَرْمِي غَرَضَيْنِ لَنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانَتِ الشَّمْسُ قِيدَ رُمْحَيْنِ أَوْ ثَلاَثَةٍ فِي عَيْنِ النَّاظِرِ مِنَ الأُفُقِ اسْوَدَّتْ فَقَالَ أَحَدُنَا لِصَاحِبِهِ انْطَلِقْ بِنَا إِلَى الْمَسْجِدِ فَوَاللَّهِ لَيُحْدِثَنَّ شَأْنُ هَذِهِ الشَّمْسِ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي أُمَّتِهِ حَدَثًا - قَالَ - فَدَفَعْنَا إِلَى الْمَسْجِدِ - قَالَ - فَوَافَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ خَرَجَ إِلَى النَّاسِ - قَالَ - فَاسْتَقْدَمَ فَصَلَّى فَقَامَ كَأَطْوَلِ قِيَامٍ قَامَ بِنَا فِي صَلاَةٍ قَطُّ مَا نَسْمَعُ لَهُ صَوْتًا ثُمَّ رَكَعَ بِنَا كَأَطْوَلِ رُكُوعٍ مَا رَكَعَ بِنَا فِي صَلاَةٍ قَطُّ مَا نَسْمَعُ لَهُ صَوْتًا ثُمَّ سَجَدَ بِنَا كَأَطْوَلِ سُجُودٍ مَا سَجَدَ بِنَا فِي صَلاَةٍ قَطُّ لاَ نَسْمَعُ لَهُ صَوْتًا ثُمَّ فَعَلَ ذَلِكَ فِي الرَّكْعَةِ الثَّانِيَةِ مِثْلَ ذَلِكَ - قَالَ - فَوَافَقَ تَجَلِّي الشَّمْسِ جُلُوسَهُ فِي الرَّكْعَةِ الثَّانِيَةِ فَسَلَّمَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَشَهِدَ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَشَهِدَ أَنَّهُ عَبْدُ اللَّهِ وَرَسُولُهُ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{1484}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Tha'labah bin 'Abbad Al-'Abdi from the people of Al-Basrah narrated that:He attended a Khutbah one day that was delivered by Samurah bin Jundub. In his Khutbah he mentioned a hadith from the Messenger of Allah (ﷺ). Samurah bin Jundub said: "One day a boy from among the Ansar and I were shooting at two targets of ours, during the time of the Messenger of Allah (ﷺ), when the sun was at a height of two or three spears as it appears to one who is looking at the horizon. The sun turned black, and we said to one another, let us go to the masjid, for by Allah (SWT) this must herald some event concerning the Messenger of Allah (ﷺ) and his ummah. We went to the masjid and we saw the Messenger of Allah (ﷺ) coming out to the people. He went forward and prayed. He stood for the longest time that he had ever stood in any prayer in which he led us, but we did not hear him saying anything. Then he bowed for the longest time that he had ever bowed in any prayer in which he led us, but we did not hear him saying anything. Then he prostrated for the longest time that he had ever prostrated in any prayer in which he led us, but we did not hear him saying anything. The he did likewise in the second rak'ah. And the eclipse ended as he was sitting at the end of the second rak'ah. The he said the salam, then he praised and glorified Allah (SWT), and bore witness that there is none worthy of worship but Allah (SWT) and he bore witness that he was the slave and Messenger of Allah." Narrated in abridged form}}
\hadithdefcmd{nasai}{1485}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ انْكَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ يَجُرُّ ثَوْبَهُ فَزِعًا حَتَّى أَتَى الْمَسْجِدَ فَلَمْ يَزَلْ يُصَلِّي بِنَا حَتَّى انْجَلَتْ فَلَمَّا انْجَلَتْ قَالَ ‏ "‏ إِنَّ نَاسًا يَزْعُمُونَ أَنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ إِلاَّ لِمَوْتِ عَظِيمٍ مِنَ الْعُظَمَاءِ وَلَيْسَ كَذَلِكَ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ عَزَّ وَجَلَّ إِنَّ اللَّهَ عَزَّ وَجَلَّ إِذَا بَدَا لِشَىْءٍ مِنْ خَلْقِهِ خَشَعَ لَهُ فَإِذَا رَأَيْتُمْ ذَلِكَ فَصَلُّوا كَأَحْدَثِ صَلاَةٍ صَلَّيْتُمُوهَا مِنَ الْمَكْتُوبَةِ ‏"‏ ‏.‏\hadithno{1485}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that An-Nu'man bin Bashir said:"The sun eclipsed during the time of the Messenger of Allah (ﷺ) and he rushed out, dragging his cloak until he came to the masjid. He continued leading us in prayer until the eclipse ended. When it ended, he said: 'People claim that the eclipse of the sun and moon only happen when a great man dies, but that is not so. Eclipses of the sun and the moon do not happen for the death or birth of anyone, but they are signs from Allah (SWT), the Mighty and Sublime. When Allah, the Mighty and Sublime, manifests Himself to anything of His creation, it humbles itself before Him, so if you see that then pray like the last obligatory prayer you did before that}}
\hadithdefcmd{nasai}{1486}{وَأَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، أَنَّ جَدَّهُ، عُبَيْدَ اللَّهِ بْنَ الْوَازِعِ حَدَّثَهُ قَالَ حَدَّثَنَا أَيُّوبُ السَّخْتِيَانِيُّ، عَنْ أَبِي قِلاَبَةَ، عَنْ قَبِيصَةَ بْنِ مُخَارِقٍ الْهِلاَلِيِّ، قَالَ كَسَفَتِ الشَّمْسُ وَنَحْنُ إِذْ ذَاكَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْمَدِينَةِ فَخَرَجَ فَزِعًا يَجُرُّ ثَوْبَهُ فَصَلَّى رَكْعَتَيْنِ أَطَالَهُمَا فَوَافَقَ انْصِرَافُهُ انْجِلاَءَ الشَّمْسِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ وَإِنَّهُمَا لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمْ مِنْ ذَلِكَ شَيْئًا فَصَلُّوا كَأَحْدَثِ صَلاَةٍ مَكْتُوبَةٍ صَلَّيْتُمُوهَا ‏"‏ ‏.‏\hadithno{1486}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Qabisah bin Mukhariq Al-Hilali said:"There was an eclipse of the sun and at the time we were with the Messenger of Allah (ﷺ) in Al-Madinah. He rushed out dragging his garment and prayed two rak'ahs, which he made lengthy. The end of his prayer coincided with the end of the eclipse. He praised and glorified Allah (SWT), then he said: 'The sun and the moon are two of the signs of Allah (SWT), and they do not become eclipsed for the death or birth of anyone. If you see anything of that, then pray like the last obligatory prayer you did before that}}
\hadithdefcmd{nasai}{1487}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُعَاذٌ، - وَهُوَ ابْنُ هِشَامٍ - قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي قِلاَبَةَ، عَنْ قَبِيصَةَ الْهِلاَلِيِّ، أَنَّ الشَّمْسَ، انْخَسَفَتْ فَصَلَّى نَبِيُّ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ رَكْعَتَيْنِ حَتَّى انْجَلَتْ ثُمَّ قَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْخَسِفَانِ لِمَوْتِ أَحَدٍ وَلَكِنَّهُمَا خَلْقَانِ مِنْ خَلْقِهِ وَإِنَّ اللَّهَ عَزَّ وَجَلَّ يُحْدِثُ فِي خَلْقِهِ مَا شَاءَ وَإِنَّ اللَّهَ عَزَّ وَجَلَّ إِذَا تَجَلَّى لِشَىْءٍ مِنْ خَلْقِهِ يَخْشَعُ لَهُ فَأَيُّهُمَا حَدَثَ فَصَلُّوا حَتَّى يَنْجَلِيَ أَوْ يُحْدِثَ اللَّهُ أَمْرًا ‏"‏ ‏.‏\hadithno{1487}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Qabisah Al-Hilali:That there was an eclipse of the sun and the Prophet of Allah (ﷺ) prayed two rak'ahs until it ended. Then he said: "The sun and the moon do not become eclipsed for the death of anyone, but they are two of His creations. Allah, the Mighty and Sublime, causes whatever He wants to happen in His creation. If Allah (SWT), the Mighty and Sublime, manifests Himself to any of His creation, it humbles itself before Him, so if either of them (solar or lunar eclipse) happens, pray until it is over or until Allah causes something to happen}}
\hadithdefcmd{nasai}{1488}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ مُعَاذِ بْنِ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي قِلاَبَةَ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا خَسَفَتِ الشَّمْسُ وَالْقَمَرُ فَصَلُّوا كَأَحْدَثِ صَلاَةٍ صَلَّيْتُمُوهَا ‏"‏ ‏.‏\hadithno{1488}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from An-Nu'man bin Bashir that :The Prophet (ﷺ) said: "If there is an eclipse of the sun or the moon, pray like the last obligatory prayer you did before that}}
\hadithdefcmd{nasai}{1489}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي قِلاَبَةَ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى حِينَ انْكَسَفَتِ الشَّمْسُ مِثْلَ صَلاَتِنَا يَرْكَعُ وَيَسْجُدُ ‏.‏\hadithno{1489}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from An-Nu'man bin Bashir that:The Messenger of Allah (ﷺ) prayed when there was an eclipse of the sun like our prayer, bowing and prostrating}}
\hadithdefcmd{nasai}{1490}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ خَرَجَ يَوْمًا مُسْتَعْجِلاً إِلَى الْمَسْجِدِ وَقَدِ انْكَسَفَتِ الشَّمْسُ فَصَلَّى حَتَّى انْجَلَتْ ثُمَّ قَالَ ‏ "‏ إِنَّ أَهْلَ الْجَاهِلِيَّةِ كَانُوا يَقُولُونَ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْخَسِفَانِ إِلاَّ لِمَوْتِ عَظِيمٍ مِنْ عُظَمَاءِ أَهْلِ الأَرْضِ وَإِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْخَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّهُمَا خَلِيقَتَانِ مِنْ خَلْقِهِ يُحْدِثُ اللَّهُ فِي خَلْقِهِ مَا يَشَاءُ فَأَيُّهُمَا انْخَسَفَ فَصَلُّوا حَتَّى يَنْجَلِيَ أَوْ يُحْدِثَ اللَّهُ أَمْرًا ‏"‏ ‏.‏\hadithno{1490}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from An-Nu'man bin Bashir that :The Prophet (ﷺ) came rushing out to the masjid one day when the sun eclipsed, and he prayed until the eclipse ended, then he said: "The people of Jahilliyyah used to say that eclipses of the sun and the moon only happened when some great man on earth died. But eclipses of the sun and the moon do not happen for the death or birth of anyone. Rather they are two of the creations of Allah (SWT) and Allah (SWT) causes to happen in His creation what He wills. Whichever of them becomes eclipsed, pray until it is over or Allah (SWT) causes something to happen}}
\hadithdefcmd{nasai}{1491}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا يُونُسُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَانْكَسَفَتِ الشَّمْسُ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَجُرُّ رِدَاءَهُ حَتَّى انْتَهَى إِلَى الْمَسْجِدِ وَثَابَ إِلَيْهِ النَّاسُ فَصَلَّى بِنَا رَكْعَتَيْنِ فَلَمَّا انْكَشَفَتِ الشَّمْسُ قَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ يُخَوِّفُ اللَّهُ عَزَّ وَجَلَّ بِهِمَا عِبَادَهُ وَإِنَّهُمَا لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمْ ذَلِكَ فَصَلُّوا حَتَّى يُكْشَفَ مَا بِكُمْ ‏"‏ ‏.‏ وَذَلِكَ أَنَّ ابْنًا لَهُ مَاتَ يُقَالُ لَهُ إِبْرَاهِيمُ فَقَالَ لَهُ نَاسٌ فِي ذَلِكَ ‏.‏\hadithno{1491}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Bakrah said:"We were with the Messenger of Allah (ﷺ) when the sun became eclipsed. The Messenger of Allah (ﷺ) went out dragging his garment, until he came to the masjid, and the people gathered around him. He led us in praying two rak'ahs and when (the eclipse) ended he said: 'The sun and the moon are two of the signs of Allah (SWT) by means of which Allah (SWT), the Mighty and Sublime, strikes fear into His slaves. They do not become eclipsed for the death or birth of anyone. If you see that, then pray until Allah (SWT)r relieves you of fear.' That was because his son named Ibrahim had died, and the people suggested to him that (the eclipse) happened because of that}}
\hadithdefcmd{nasai}{1492}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ أَشْعَثَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى رَكْعَتَيْنِ مِثْلَ صَلاَتِكُمْ هَذِهِ وَذَكَرَ كُسُوفَ الشَّمْسِ ‏.‏\hadithno{1492}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Bakrah that:The Messenger of Allah (ﷺ) prayed two rak'ahs like this prayer of yours, and he mentioned the eclipse of the sun}}
\hadithdefcmd{nasai}{1493}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ خَسَفَتِ الشَّمْسُ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ مَعَهُ فَقَامَ قِيَامًا طَوِيلاً قَرَأَ نَحْوًا مِنْ سُورَةِ الْبَقَرَةِ - قَالَ - ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ ثُمَّ قَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ ثُمَّ انْصَرَفَ وَقَدْ تَجَلَّتِ الشَّمْسُ فَقَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمْ ذَلِكَ فَاذْكُرُوا اللَّهَ عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ رَأَيْنَاكَ تَنَاوَلْتَ شَيْئًا فِي مَقَامِكَ هَذَا ثُمَّ رَأَيْنَاكَ تَكَعْكَعْتَ ‏.‏ قَالَ ‏"‏ إِنِّي رَأَيْتُ الْجَنَّةَ أَوْ أُرِيتُ الْجَنَّةَ فَتَنَاوَلْتُ مِنْهَا عُنْقُودًا وَلَوْ أَخَذْتُهُ لأَكَلْتُمْ مِنْهُ مَا بَقِيَتِ الدُّنْيَا وَرَأَيْتُ النَّارَ فَلَمْ أَرَ كَالْيَوْمِ مَنْظَرًا قَطُّ وَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏ ‏.‏ قَالُوا لِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بِكُفْرِهِنَّ ‏"‏ ‏.‏ قِيلَ يَكْفُرْنَ بِاللَّهِ قَالَ ‏"‏ يَكْفُرْنَ الْعَشِيرَ وَيَكْفُرْنَ الإِحْسَانَ لَوْ أَحْسَنْتَ إِلَى إِحْدَاهُنَّ الدَّهْرَ ثُمَّ رَأَتْ مِنْكَ شَيْئًا قَالَتْ مَا رَأَيْتُ مِنْكَ خَيْرًا قَطُّ ‏"‏ ‏.‏\hadithno{1493}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin Abbas said:"There was an eclipse of the sun and the Messenger of Allah (ﷺ) prayed and the people with him. He stood for long time reciting something like Surah Al-Baqarah, then he raised (his head) and stood for a long time, then he raised (his head) and stood for a long time which was shorter than the first time. Then he bowed for a long time, which was shorter than the first time, then he prostrated. Then he got up and stood for a long time, which was shorter than the first time, then he bowed for a long time, which was shorter than the first time, then he raised (his head) and stood for a long time, which was shorter than the first time. Then he bowed for a long time, which was shorter than the first time, then he prostrated, then he finished (his prayer) and the sun had been clear. He said: 'The sun and the moon are two of the signs of Allah (SWT) and they do not become eclipsed for the death or birth of anyone. If you see that then remember Allah (SWT) the Mighty and Sublime.' They said: 'O Messenger of Allah (ﷺ), we saw you stretching out your hand when you were standing, then we saw you moving backward. He said: 'I saw Paradise-or it was shown to me- and I reached out to a take a bunch of its fruits. If I ha taken it you would have eaten from it for as long as this world lasts. And I saw Hell and I have never seen anything like it, and I saw that most of its inhabitants are women.' They said: "Why, O Messenger of Allah (ﷺ)? He said: 'Because of their ingratitude.' It was said: 'Are they ungrateful to Allah?' He said: 'They are ungrateful to their husbands and they are ungrateful for kind treatment. If you are kind to one of them for a lifetime, then she sees (one) bad thing from you, she will say: I have never seen anything good from you}}
\hadithdefcmd{nasai}{1494}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ نَمِرٍ، أَنَّهُ سَمِعَ الزُّهْرِيَّ، يُحَدِّثُ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ صَلَّى أَرْبَعَ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ وَجَهَرَ فِيهَا بِالْقِرَاءَةِ كُلَّمَا رَفَعَ رَأْسَهُ قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏\hadithno{1494}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aishah that:The Messenger of Allah (ﷺ) prayed, bowing four times, and he recited loudly, and every time he raised his head he said: "Sami Allahu liman hamidah. Rabbana wa lakal-hamd (Allah hears those who praise Him, Our Lord to You be praise)}}
\hadithdefcmd{nasai}{1495}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنِ ابْنِ عَبَّادٍ، - رَجُلٌ مِنْ بَنِي عَبْدِ الْقَيْسِ - عَنْ سَمُرَةَ، ‏.‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِهِمْ فِي كُسُوفِ الشَّمْسِ لاَ نَسْمَعُ لَهُ صَوْتًا ‏.‏\hadithno{1495}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Samurah that:The Prophet (ﷺ) led them in prayer during an eclipse of the sun, and we did not hear him say anything}}
\hadithdefcmd{nasai}{1496}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْمِسْوَرِ الزُّهْرِيُّ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ فَأَطَالَ - قَالَ شُعْبَةُ وَأَحْسَبُهُ قَالَ فِي السُّجُودِ نَحْوَ ذَلِكَ - وَجَعَلَ يَبْكِي فِي سُجُودِهِ وَيَنْفُخُ وَيَقُولُ ‏"‏ رَبِّ لَمْ تَعِدْنِي هَذَا وَأَنَا أَسْتَغْفِرُكَ لَمْ تَعِدْنِي هَذَا وَأَنَا فِيهِمْ ‏"‏ ‏.‏ فَلَمَّا صَلَّى قَالَ ‏"‏ عُرِضَتْ عَلَىَّ الْجَنَّةُ حَتَّى لَوْ مَدَدْتُ يَدِي تَنَاوَلْتُ مِنْ قُطُوفِهَا وَعُرِضَتْ عَلَىَّ النَّارُ فَجَعَلْتُ أَنْفُخُ خَشْيَةَ أَنْ يَغْشَاكُمْ حَرُّهَا وَرَأَيْتُ فِيهَا سَارِقَ بَدَنَتَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرَأَيْتُ فِيهَا أَخَا بَنِي دُعْدُعٍ سَارِقَ الْحَجِيجِ فَإِذَا فُطِنَ لَهُ قَالَ هَذَا عَمَلُ الْمِحْجَنِ وَرَأَيْتُ فِيهَا امْرَأَةً طَوِيلَةً سَوْدَاءَ تُعَذَّبُ فِي هِرَّةٍ رَبَطَتْهَا فَلَمْ تُطْعِمْهَا وَلَمْ تَسْقِهَا وَلَمْ تَدَعْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ حَتَّى مَاتَتْ وَإِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ فَإِذَا انْكَسَفَتْ إِحْدَاهُمَا - أَوْ قَالَ فَعَلَ أَحَدُهُمَا شَيْئًا مِنْ ذَلِكَ - فَاسْعَوْا إِلَى ذِكْرِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{1496}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abdullah bin Amr said:"The sun eclipsed during the time of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) prayed and stood for a long time, then he bowed for a long time, then he stood up and (remained standing) for a long time." (One of the narrators) Shu'bh said: "I think he said something similar concerning prostration."- "He started weeping and blowing during his prostration and said: 'Lord, You did not tell me that You would do that while I am asking You for forgiveness; You did not tell me that You would do that while I was still among them.' When he finished praying he said: "Paradise was shown to me, and if I had stretched forth my hand I could have taken some of its fruits. And Hell was shown to me, so I started blowing for fear that its heat might overwhelm you. I saw therein the thief who stole the two camels of the Messenger of Allah (ﷺ); and I saw therein the brother of Banu As-Du'du; the thief who stole from the pilgrims, and when he was caught he said: The crooked stick did it; and I saw therein a tall black woman who was being punished because of a cat she tied up and did not feed or give it water, and she did not let it eat of the vermin of the earth, until it died. Then sun and the moon do not become eclipsed for the death or birth of anyone, but they are two of the signs of Allah. If one of them becomes eclipsed'- or he said: 'if one of them does anything like that'- 'then hasten to remember Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{1497}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرٍ، عَنِ الْوَلِيدِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ نَمِرٍ، أَنَّهُ سَأَلَ الزُّهْرِيَّ عَنْ سُنَّةِ، صَلاَةِ الْكُسُوفِ فَقَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ كَسَفَتِ الشَّمْسُ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً فَنَادَى أَنَّ الصَّلاَةَ جَامِعَةً فَاجْتَمَعَ النَّاسُ فَصَلَّى بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَبَّرَ ثُمَّ قَرَأَ قِرَاءَةً طَوِيلَةً ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً مِثْلَ قِيَامِهِ أَوْ أَطْوَلَ ثُمَّ رَفَعَ رَأْسَهُ وَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ قِرَاءَةً طَوِيلَةً هِيَ أَدْنَى مِنَ الْقِرَاءَةِ الأُولَى ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً هُوَ أَدْنَى مِنَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ كَبَّرَ فَسَجَدَ سُجُودًا طَوِيلاً مِثْلَ رُكُوعِهِ أَوْ أَطْوَلَ ثُمَّ كَبَّرَ فَرَفَعَ رَأْسَهُ ثُمَّ كَبَّرَ فَسَجَدَ ثُمَّ كَبَّرَ فَقَامَ فَقَرَأَ قِرَاءَةً طَوِيلةً هِيَ أَدْنَى مِنَ الأُولَى ثُمَّ كَبَّرَ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً هُوَ أَدْنَى مِنَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ قِرَاءَةً طَوِيلَةً وَهِيَ أَدْنَى مِنَ الْقِرَاءَةَ الأُولَى فِي الْقِيَامِ الثَّانِي ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ كَبَّرَ فَرَفَعَ رَأْسَهُ فَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ كَبَّرَ فَسَجَدَ أَدْنَى مِنْ سُجُودِهِ الأَوَّلِ ثُمَّ تَشَهَّدَ ثُمَّ سَلَّمَ فَقَامَ فِيهِمْ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْخَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ فَأَيُّهُمَا خُسِفَ بِهِ أَوْ بِأَحَدِهِمَا فَافْزَعُوا إِلَى اللَّهِ عَزَّ وَجَلَّ بِذِكْرِ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1497}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Aishah said:"There was an eclipse of the sun and the Messenger of Allah (ﷺ) ordered a man to call out: As-salatu jami'ah (prayer is about to begin in congregation). The people gathered and the Messenger of Allah (ﷺ) led them in prayer. He said the takbir, then he recited at length. Then he said the takbir and bowed for a long time, as long as he had recited or longer. Then he raised his head and said: Sami Allahu liman hamidah (Allah hears those who praise Him) Then he recited at length, but it was shorter than the first time, then he said the takbir and bowed for a long time, but it was shorter than the first time. Then he raised his head and said: 'Sami Allahu liman hamidah (Allah hears those who praise Him). Then he said the takbir and prostrated for a long time, as long as he had bowed or longer. Then he said the takbir and raised his head, then he said the takbir and prostrated. Then he said the takbir and stood up, and recited for a long time that was shorter than the first time. Then he said the takbir and bowed for a long time that was shorter than the first time. Then he raised his head and said: Sami' Allahu liman hamidah. (Allah hears those who praise Him). Then he recited for a long time that was shorter than the first recitation in the second standing. Then he said the takbir and bowed for a long time that was shorter than the first time. Then he raised his head and said: Sami Allahu liman hamidah (Allah hears those who praise Him). Then he said the takbir and prostrated for a long time that was shorter than the first time. Then he recited the tashahhud, then he said the taslim. Then he stood before them and praised and glorified Allah, then he said: 'The sun and the moon do not become eclipsed for the death or birth of anyone, but they are two of the signs of Allah (SWT). Whichever of them becomes eclipsed, turn to Allah (SWT), the Mighty and Sublime, and pray}}
\hadithdefcmd{nasai}{1498}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا مُوسَى بْنُ دَاوُدَ، قَالَ حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْكُسُوفِ فَقَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ رَفَعَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ قَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ رَفَعَ ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ ثُمَّ رَفَعَ ثُمَّ انْصَرَفَ ‏.‏\hadithno{1498}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Asma' bint Abi Bakr said:The Messenger of Allah (ﷺ) prayed during an eclipse. He stood for a long time, then he bowed for a long time, then he stood up and (remained standing) for a long time, then he bowed for a long time, then he stood up, then he prostrated for a long time, then he stood up and (remained standing) for a long time, then he bowed for a long time, then he stood up, then he prostrated for a long time, then he sat up, then he prostrated for a long time, then he sat up and then he finished}}
\hadithdefcmd{nasai}{1499}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ ابْنِ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عَمْرَةَ، حَدَّثَتْهُ أَنَّ عَائِشَةَ قَالَتْ إِنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ مَخْرَجًا فَخُسِفَ بِالشَّمْسِ فَخَرَجْنَا إِلَى الْحُجْرَةِ فَاجْتَمَعَ إِلَيْنَا نِسَاءٌ وَأَقْبَلَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَذَلِكَ ضَحْوَةً فَقَامَ قِيَامًا طَوِيلاً ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ رَأْسَهُ فَقَامَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ دُونَ رُكُوعِهِ ثُمَّ سَجَدَ ثُمَّ قَامَ الثَّانِيَةَ فَصَنَعَ مِثْلَ ذَلِكَ إِلاَّ أَنَّ قِيَامَهُ وَرُكُوعَهُ دُونَ الرَّكْعَةِ الأُولَى ثُمَّ سَجَدَ وَتَجَلَّتِ الشَّمْسُ فَلَمَّا انْصَرَفَ قَعَدَ عَلَى الْمِنْبَرِ فَقَالَ فِيمَا يَقُولُ ‏ "‏ إِنَّ النَّاسَ يُفْتَنُونَ فِي قُبُورِهِمْ كَفِتْنَةِ الدَّجَّالِ ‏"‏ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{1499}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah said:"The Prophet (ﷺ) went out and the sun became eclipsed. We went out to the apartment and some women gathered around us. The Messenger of Allah (ﷺ) turned to us, and that was at the time of the forenoon. He stood for a long time, then he bowed for a long time, then he raised his head and stood for a shorter time than the first, then he bowed for a shorter time than the first, then he prostrated. Then he stood up again and did the same, except that he stood and bowed for a shorter time than in the first rak'ah. Then he prostrated and the eclipse ended. When he had finished he sat on the minbar and among the things he said was : 'The people will be tried in their graves like the trial of the Dajjal}}
\hadithdefcmd{nasai}{1500}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدَةُ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ فَصَلَّى فَأَطَالَ الْقِيَامَ جِدًّا ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ جِدًّا ثُمَّ رَفَعَ فَأَطَالَ الْقِيَامَ جِدًّا وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ ثُمَّ رَفَعَ رَأْسَهُ فَأَطَالَ الْقِيَامَ وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ فَأَطَالَ الْقِيَامَ وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ فَفَرَغَ مِنْ صَلاَتِهِ وَقَدْ جُلِّيَ عَنِ الشَّمْسِ فَخَطَبَ النَّاسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمْ ذَلِكَ فَصَلُّوا وَتَصَدَّقُوا وَاذْكُرُوا اللَّهَ عَزَّ وَجَلَّ ‏"‏ ‏.‏ وَقَالَ ‏"‏ يَا أُمَّةَ مُحَمَّدٍ إِنَّهُ لَيْسَ أَحَدٌ أَغْيَرَ مِنَ اللَّهِ عَزَّ وَجَلَّ أَنْ يَزْنِيَ عَبْدُهُ أَوْ أَمَتُهُ يَا أُمَّةَ مُحَمَّدٍ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏"‏ ‏.‏\hadithno{1500}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"There was an eclipse of the sun during the time of the Messenger of Allah (ﷺ). He stood and prayed, standing for a very long time, then he bowed for a very long time. Then he stood up and (remained standing) for a very long time, but shorter than the first time. Then he bowed for a very long time, but shorter than the first time. Then he prostrated, then he raised his head and stood for a long time, but it was shorter than the first time. The he stood up and (remained standing) for a long time, but it was shorter than the first time. Then he prostrated, and when he finished his prayer, the eclipse had ended. He addressed the people and praised and glorified Allah, then he said: 'The sun and the moon do not become eclipsed for the death or birth of anyone. If you see that then pray, give in charity, and remember Allah, the Mighty and Sublime.' And he said: 'O Ummah of Muhammad! There is no one who is more jealous than Allah (SWT) when His male or female slave commits Zina. O Ummah of Muhammad, if you knew what I know, you would laugh little and weep much}}
\hadithdefcmd{nasai}{1501}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ ثَعْلَبَةَ بْنِ عِبَادٍ، عَنْ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ حِينَ انْكَسَفَتِ الشَّمْسُ فَقَالَ ‏ "‏ أَمَّا بَعْدُ ‏"‏ ‏.‏\hadithno{1501}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Samurah that:The Prophet (ﷺ) delivered a Khutbah when the sun eclipsed and he said: 'Amma ba'd (to proceed)}}
\hadithdefcmd{nasai}{1502}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا يُونُسُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَانْكَسَفَتِ الشَّمْسُ فَقَامَ إِلَى الْمَسْجِدِ يَجُرُّ رِدَاءَهُ مِنَ الْعَجَلَةِ فَقَامَ إِلَيْهِ النَّاسُ فَصَلَّى رَكْعَتَيْنِ كَمَا يُصَلُّونَ فَلَمَّا انْجَلَتْ خَطَبَنَا فَقَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ يُخَوِّفُ بِهِمَا عِبَادَهُ وَإِنَّهُمَا لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ فَإِذَا رَأَيْتُمْ كُسُوفَ أَحَدِهِمَا فَصَلُّوا وَادْعُوا حَتَّى يَنْكَشِفَ مَا بِكُمْ ‏"‏ ‏.‏\hadithno{1502}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Bakrah said:"We were with the Prophet (ﷺ) and the sun became eclipsed. He got up and went to the masjid, dragging his garment in haste. The people stood with him and he prayed two rak'ahs as they usually prayed. When the eclipse ended he addressed us and said 'The sun and the moon are two of the signs of Allah (SWT), with which He strikes fear into His slaves. They do not become eclipsed for the death or birth of anyone. If you see either of them being eclipsed, then pray and supplicate until it removed it from you}}
\hadithdefcmd{nasai}{1503}{أَخْبَرَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْمَسْرُوقِيُّ، عَنْ أَبِي أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ خَسَفَتِ الشَّمْسُ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَزِعًا يَخْشَى أَنْ تَكُونَ السَّاعَةُ فَقَامَ حَتَّى أَتَى الْمَسْجِدَ فَقَامَ يُصَلِّي بِأَطْوَلِ قِيَامٍ وَرُكُوعٍ وَسُجُودٍ مَا رَأَيْتُهُ يَفْعَلُهُ فِي صَلاَتِهِ قَطُّ ثُمَّ قَالَ ‏ "‏ إِنَّ هَذِهِ الآيَاتِ الَّتِي يُرْسِلُ اللَّهُ لاَ تَكُونُ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّ اللَّهَ يُرْسِلُهَا يُخَوِّفُ بِهَا عِبَادَهُ فَإِذَا رَأَيْتُمْ مِنْهَا شَيْئًا فَافْزَعُوا إِلَى ذِكْرِهِ وَدُعَائِهِ وَاسْتِغْفَارِهِ ‏"‏ ‏.‏\hadithno{1503}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa said:"There was an eclipse of the sun, and the Messenger of Allah (ﷺ) got up in a rush, fearing that it might be the Hour. He went to the masjid, where he stood and prayed, standing, bowing and prostrating for the longest time that I ever saw him do in prayer. Then he said: 'These signs that Allah (SWT) sends do not occur for the death or birth of anyone, but Allah (SWT) sends them to strike fear into His slaves. If you see any of these things, then hasten to remember Him, call upon Him supplicate and ask for His forgiveness}}
